# Nekro Agent 沙盒环境

这是 Nekro Agent 的执行沙盒环境，提供了多种数据处理和可视化功能。

## 功能特性

- 数据分析：pandas, numpy, scipy, scikit-learn
- 图像处理：opencv-python, imageio, pytesseract
- 文档处理：pymupdf, docx, python-pptx, openpyxl
- 数学计算：sympy, numpy
- 可视化：matplotlib, networkx
- 图表生成：py-mermaid, graphviz
